@@ -1,7 +1,4 @@
 '''
-
-convenience functions to help speed up the work
-
 '''
 
 import os
@@ -21,8 +18,62 @@ if importing_dir == None:
 
 class getpath(str):
     '''
+# IMPORTING
+
+from getpaths import getpath
+
+
+# USING CURRENT FILE PATH
+
+current_dir = getpath() # current file's path
+
+
+# USER-SPECIFIED PATH
+
+custom_dir = getpath('a','b',custom=True)
+print(custom_dir)
+# /a/b
+
+
+# ADD FILES
+
+custom_dir/'example.txt'
+# /a/b/example.txt
+
+custom_dir.add('/a/example.txt')
+# /a/b/example.txt
+
+
+#  GO UP THE DIRECTORY
+
+custom_dir = getpath('a','b',custom=True)
+
+custom_dir/'..'
+# /a
+
+custom_dir.add('..')
+# /a
+
+custom_dir.up(1)
+# /a
+
+
+# LIST EXISTING FILES AND FOLDERS
+
+custom_dir.ls()
+# /a/b/example.txt
+# throws error if path does not exist
+
     '''
-    def __new__(cls, *args, custom=False):
+    def __new__(cls, *args, custom=False, start_at_root=True):
+
+        # adds separator at the beginning
+        if start_at_root == True and custom == True:
+            if args[0][0] != os.path.sep:
+                arguments = list(args)
+                first_arg = os.path.sep + arguments[0]
+                return getpath(first_arg, *arguments[1:], custom=True)
+
         if custom:
             paths = []
         else:
@@ -35,6 +86,7 @@ class getpath(str):
                 paths.append(arguments)
         
         path = os.sep.join(paths)
+
         return str.__new__(cls, path)
     
     def __init(self):
